[m-rev.] trivial diff: add a missing MR_ prefix
Julien Fischer
juliensf at csse.unimelb.edu.au
Wed Nov 11 18:09:34 AEDT 2009
Fix a problem introduced by the recent change to mercury_boostrap.h.
compiler/export.m:
Add a missing MR_ prefix.
Julien.
Index: compiler/export.m
===================================================================
RCS file: /home/mercury/mercury1/repository/mercury/compiler/export.m,v
retrieving revision 1.125
diff -u -r1.125 export.m
--- compiler/export.m 14 Oct 2009 05:28:32 -0000 1.125
+++ compiler/export.m 11 Nov 2009 07:04:35 -0000
@@ -611,10 +611,10 @@
ConvertedRval = "MR_float_to_word(" ++ Rval ++ ")"
;
BuiltinType = builtin_type_char,
% We need to explicitly cast to UnsignedChar
% to avoid problems with C compilers for which `char'
% is signed.
- ConvertedRval = "(UnsignedChar) " ++ Rval
+ ConvertedRval = "(MR_UnsignedChar) " ++ Rval
;
BuiltinType = builtin_type_int,
ConvertedRval = Rval
--------------------------------------------------------------------------
mercury-reviews mailing list
Post messages to: mercury-reviews at csse.unimelb.edu.au
Administrative Queries: owner-mercury-reviews at csse.unimelb.edu.au
Subscriptions: mercury-reviews-request at csse.unimelb.edu.au
--------------------------------------------------------------------------
More information about the reviews
mailing list
@@ -611,10 +611,10 @@
;
BuiltinType = builtin_type_char,
- % We need to explicitly cast to UnsignedChar
+ % We need to explicitly cast to MR_UnsignedChar
% to avoid problems with C compilers for which `char'
% is signed.